@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
-## Copyright 2007-2010 by LivingLogic AG, Bayreuth/Germany
-## Copyright 2007-2010 by Walter Dörwald
+## Copyright 2007-2013 by LivingLogic AG, Bayreuth/Germany
+## Copyright 2007-2013 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
-## See ll/__init__.py for the license
+## See ll/xist/__init__.py for the license
 
 
 """
@@ -267,7 +267,7 @@ class guid(xsc.Element):
 	"""
 	xmlns = xmlns
 	class Attrs(xsc.Element.Attrs):
-		class isPermaLink(xsc.URLAttr):
+		class isPermaLink(xsc.TextAttr):
 			values = ("false", "true")
 
 
